==> peony-3.1.0-1.src.tar.gz: peony-3.1.0/translations/peony-qt-desktop/peony-qt-desktop_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>Peony::DesktopIconView</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.h" line="80"/>
        <source>Desktop Icon View</source>
        <translation>Masaüstü Simgelerini Göster</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="559"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="641"/>
        <source>set background</source>
        <translation>Arkaplanı Değiştir</translation>
    </message>
    <message>
        <source>Delete file Warning</source>
        <translation type="obsolete">Dosyayı Sil Uyarısı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="805"/>
        <source>Open Link failed</source>
        <translation type="unfinished">Bağlantı Açılamadı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="806"/>
        <source>File not exist, do you want to delete the link file?</source>
        <translation type="unfinished">Dosya mevcut değil, bağlantı dosyasını silmek istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="821"/>
        <source>Open failed</source>
        <translation type="unfinished">Açma hatalı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="822"/>
        <source>Open directory failed, you have no permission!</source>
        <translation type="unfinished">Dizin açılamadı, izniniz yok!</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopMenu</name>
    <message>
        <source>&amp;Open in new Window</source>
        <translation type="vanished">Yeni Pencerede Aç</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="vanished">Tümünü Seç</translation>
    </message>
    <message>
        <source>&amp;Open &quot;%1&quot;</source>
        <translation type="vanished">&quot;%1&quot; Aç</translation>
    </message>
    <message>
        <source>Open &quot;%1&quot; &amp;with...</source>
        <translation type="vanished">&quot;%1&quot; &amp;ile aç...</translation>
    </message>
    <message>
        <source>&amp;More applications...</source>
        <translation type="vanished">&amp;Daha fazla uygulama...</translation>
    </message>
    <message>
        <source>Open &quot;%1&quot; with...</source>
        <translation type="vanished">&quot;%1&quot; ile aç...</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="vanished">&amp;Aç</translation>
    </message>
    <message>
        <source>&amp;Open %1 selected files</source>
        <translation type="vanished">Seçilen %1 dosyasını aç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="228"/>
        <source>Reverse Select</source>
        <translation>Seçimi Ters Çevir</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation type="vanished">&amp;Yeni...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="242"/>
        <source>New...</source>
        <translation type="unfinished">Yeni...</translation>
    </message>
    <message>
        <source>Empty &amp;File</source>
        <translation type="vanished">&amp;Boş Dosya</translation>
    </message>
    <message>
        <source>&amp;Folder</source>
        <translation type="vanished">&amp;Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="319"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="336"/>
        <source>View Type...</source>
        <translation>Görünüm Türü...</translation>
    </message>
    <message>
        <source>&amp;Small</source>
        <translation type="vanished">&amp;Küçük</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation type="vanished">&amp;Normal</translation>
    </message>
    <message>
        <source>&amp;Large</source>
        <translation type="vanished">&amp;Büyük</translation>
    </message>
    <message>
        <source>&amp;Huge</source>
        <translation type="vanished">&amp;Daha Büyük</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="109"/>
        <source>Open in new Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="114"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="137"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="165"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="190"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="201"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="145"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="170"/>
        <source>Open with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="158"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="184"/>
        <source>More applications...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="204"/>
        <source>Open %1 selected files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="305"/>
        <source>Empty File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="315"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="342"/>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="347"/>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="352"/>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="357"/>
        <source>Huge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="387"/>
        <source>Sort By...</source>
        <translation>Sırala...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="392"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="394"/>
        <source>File Type</source>
        <translation>Dosya Türü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="395"/>
        <source>File Size</source>
        <translation>Dosya Boyutu</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="467"/>
        <source>Clean the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="481"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="491"/>
        <source>Delete to trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="393"/>
        <source>Modified Date</source>
        <translation>Düzenleme Tarihi</translation>
    </message>
    <message>
        <source>Delete file Warning</source>
        <translation type="obsolete">Dosyayı Sil Uyarısı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="485"/>
        <source>Cut</source>
        <translation type="unfinished">Kes</translation>
    </message>
    <message>
        <source>&amp;Delete to trash</source>
        <translation type="vanished">Çöp Kutusuna Taşı</translation>
    </message>
    <message>
        <source>Delete forever</source>
        <translation type="vanished">Kalıcı olarak sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="504"/>
        <source>Rename</source>
        <translation type="unfinished">Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="511"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="517"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="531"/>
        <source>Properties</source>
        <translation type="unfinished">Özellikler</translation>
    </message>
    <message>
        <source>P&amp;roperties</source>
        <translation type="obsolete">Özellikler</translation>
    </message>
    <message>
        <source>Sort Order...</source>
        <translation type="vanished">Sıralama Düzeni...</translation>
    </message>
    <message>
        <source>Ascending Order</source>
        <translation type="vanished">Artan Düzen</translation>
    </message>
    <message>
        <source>Descending Order</source>
        <translation type="vanished">Azalan Düzen</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="vanished">Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="vanished">Uzaklaştır</translation>
    </message>
    <message>
        <source>&amp;Restore all</source>
        <translation type="vanished">Tümünü Onar</translation>
    </message>
    <message>
        <source>&amp;Clean the trash</source>
        <translation type="vanished">Çöpü Temizle</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="469"/>
        <source>Delete Permanently</source>
        <translation>Kalıcı Olarak Sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="469"/>
        <source>Are you sure that you want to delete these files? Once you start a deletion, the files deleting will never be restored again.</source>
        <translation>Bu dosyaları silmek istediğinizden emin misiniz? Bir silme işlemini başlattığınızda, silinen dosyalar bir daha geri yüklenmeyecektir.</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="vanished">&amp;Kopyala</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="vanished">Kes</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">Sil</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="vanished">Yeniden Adlandır</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="vanished">Yapıştır</translation>
    </message>
    <message>
        <source>&amp;Refresh</source>
        <translation type="vanished">Yenile</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation type="vanished">Özellikler</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopWindow</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-window.cpp" line="96"/>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <source>set background</source>
        <translation type="vanished">Arkaplanı Değiştir</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="vanished">Yeni Klasör</translation>
    </message>
</context>
<context>
    <name>PeonyDesktopApplication</name>
    <message>
        <source>Close the peony-qt desktop window</source>
        <translation type="vanished">Masaüstünü kapatın ve çıkın</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="151"/>
        <source>peony-qt-desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <source>Peony-Qt Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="253"/>
        <source>Close the peony desktop window</source>
        <translation>Peony masaüstü penceresini kapat</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="256"/>
        <source>Take over the dbus service.</source>
        <translation>Dbus servisini al</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="259"/>
        <source>Take over the desktop displaying</source>
        <translation>Masaüstü görüntülemeyi al</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="350"/>
        <source>set background</source>
        <translation type="unfinished">Arkaplanı Değiştir</translation>
    </message>
</context>
</TS>

==> peony-3.2.4-1.src.tar.gz: peony-3.2.4/translations/peony-qt-desktop/peony-qt-desktop_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>Peony::DesktopIconView</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.h" line="81"/>
        <source>Desktop Icon View</source>
        <translation>Masaüstü Simgelerini Göster</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="575"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="667"/>
        <source>set background</source>
        <translation>Arkaplanı Değiştir</translation>
    </message>
    <message>
        <source>Delete file Warning</source>
        <translation type="obsolete">Dosyayı Sil Uyarısı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="884"/>
        <source>Open Link failed</source>
        <translation type="unfinished">Bağlantı Açılamadı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="885"/>
        <source>File not exist, do you want to delete the link file?</source>
        <translation type="unfinished">Dosya mevcut değil, bağlantı dosyasını silmek istiyor musunuz?</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="900"/>
        <source>Open failed</source>
        <translation type="unfinished">Açma hatalı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="901"/>
        <source>Open directory failed, you have no permission!</source>
        <translation type="unfinished">Dizin açılamadı, izniniz yok!</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopItemModel</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-item-model.cpp" line="552"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-item-model.cpp" line="554"/>
        <source>Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::DesktopMenu</name>
    <message>
        <source>&amp;Open in new Window</source>
        <translation type="vanished">Yeni Pencerede Aç</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="vanished">Tümünü Seç</translation>
    </message>
    <message>
        <source>&amp;Open &quot;%1&quot;</source>
        <translation type="vanished">&quot;%1&quot; Aç</translation>
    </message>
    <message>
        <source>Open &quot;%1&quot; &amp;with...</source>
        <translation type="vanished">&quot;%1&quot; &amp;ile aç...</translation>
    </message>
    <message>
        <source>&amp;More applications...</source>
        <translation type="vanished">&amp;Daha fazla uygulama...</translation>
    </message>
    <message>
        <source>Open &quot;%1&quot; with...</source>
        <translation type="vanished">&quot;%1&quot; ile aç...</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="vanished">&amp;Aç</translation>
    </message>
    <message>
        <source>&amp;Open %1 selected files</source>
        <translation type="vanished">Seçilen %1 dosyasını aç</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="237"/>
        <source>Reverse Select</source>
        <translation>Seçimi Ters Çevir</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation type="vanished">&amp;Yeni...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="251"/>
        <source>New...</source>
        <translation type="unfinished">Yeni...</translation>
    </message>
    <message>
        <source>Empty &amp;File</source>
        <translation type="vanished">&amp;Boş Dosya</translation>
    </message>
    <message>
        <source>&amp;Folder</source>
        <translation type="vanished">&amp;Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="334"/>
        <source>New Folder</source>
        <translation>Yeni Klasör</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="351"/>
        <source>View Type...</source>
        <translation>Görünüm Türü...</translation>
    </message>
    <message>
        <source>&amp;Small</source>
        <translation type="vanished">&amp;Küçük</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation type="vanished">&amp;Normal</translation>
    </message>
    <message>
        <source>&amp;Large</source>
        <translation type="vanished">&amp;Büyük</translation>
    </message>
    <message>
        <source>&amp;Huge</source>
        <translation type="vanished">&amp;Daha Büyük</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="109"/>
        <source>Open in new Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="114"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="137"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="165"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="199"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="210"/>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="145"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="170"/>
        <source>Open with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="158"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="193"/>
        <source>More applications...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="213"/>
        <source>Open %1 selected files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="320"/>
        <source>Empty File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="330"/>
        <source>Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="357"/>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="362"/>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="367"/>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="372"/>
        <source>Huge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="402"/>
        <source>Sort By...</source>
        <translation>Sırala...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="407"/>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="409"/>
        <source>File Type</source>
        <translation>Dosya Türü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="410"/>
        <source>File Size</source>
        <translation>Dosya Boyutu</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="482"/>
        <source>Clean the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="496"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="521"/>
        <source>Delete to trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="408"/>
        <source>Modified Date</source>
        <translation>Düzenleme Tarihi</translation>
    </message>
    <message>
        <source>Delete file Warning</source>
        <translation type="obsolete">Dosyayı Sil Uyarısı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="500"/>
        <source>Cut</source>
        <translation type="unfinished">Kes</translation>
    </message>
    <message>
        <source>&amp;Delete to trash</source>
        <translation type="vanished">Çöp Kutusuna Taşı</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="530"/>
        <source>Delete forever</source>
        <translation>Kalıcı olarak sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="538"/>
        <source>Rename</source>
        <translation type="unfinished">Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="545"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="551"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="565"/>
        <source>Properties</source>
        <translation type="unfinished">Özellikler</translation>
    </message>
    <message>
        <source>P&amp;roperties</source>
        <translation type="obsolete">Özellikler</translation>
    </message>
    <message>
        <source>Sort Order...</source>
        <translation type="vanished">Sıralama Düzeni...</translation>
    </message>
    <message>
        <source>Ascending Order</source>
        <translation type="vanished">Artan Düzen</translation>
    </message>
    <message>
        <source>Descending Order</source>
        <translation type="vanished">Azalan Düzen</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="vanished">Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="vanished">Uzaklaştır</translation>
    </message>
    <message>
        <source>&amp;Restore all</source>
        <translation type="vanished">Tümünü Onar</translation>
    </message>
    <message>
        <source>&amp;Clean the trash</source>
        <translation type="vanished">Çöpü Temizle</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="484"/>
        <source>Delete Permanently</source>
        <translation>Kalıcı Olarak Sil</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="484"/>
        <source>Are you sure that you want to delete these files? Once you start a deletion, the files deleting will never be restored again.</source>
        <translation>Bu dosyaları silmek istediğinizden emin misiniz? Bir silme işlemini başlattığınızda, silinen dosyalar bir daha geri yüklenmeyecektir.</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="vanished">&amp;Kopyala</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="vanished">Kes</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">Sil</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="vanished">Yeniden Adlandır</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="vanished">Yapıştır</translation>
    </message>
    <message>
        <source>&amp;Refresh</source>
        <translation type="vanished">Yenile</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation type="vanished">Özellikler</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopWindow</name>
    <message>
        <source>Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <source>set background</source>
        <translation type="vanished">Arkaplanı Değiştir</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="vanished">Yeni Klasör</translation>
    </message>
</context>
<context>
    <name>PeonyDesktopApplication</name>
    <message>
        <source>Close the peony-qt desktop window</source>
        <translation type="vanished">Masaüstünü kapatın ve çıkın</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="169"/>
        <source>peony-qt-desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <source>Peony-Qt Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="vanished">Masaüstü</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="371"/>
        <source>Close the peony desktop window</source>
        <translation>Peony masaüstü penceresini kapat</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="374"/>
        <source>Take over the dbus service.</source>
        <translation>Dbus servisini al</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="377"/>
        <source>Take over the desktop displaying</source>
        <translation>Masaüstü görüntülemeyi al</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="380"/>
        <source>Setup backgrounds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>set background</source>
        <translation type="obsolete">Arkaplanı Değiştir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../peony-qt-desktop/desktopbackgroundwindow.cpp" line="57"/>
        <source>set background</source>
        <translation type="unfinished">Arkaplanı Değiştir</translation>
    </message>
</context>
</TS>
